$date = Get-Date -Format "yyyy-MM-dd HH:mm:ss"

if (Test-Path -Path $Env:drv_dir) {
	$DriverPath = Get-Item $Env:drv_dir
	Write-Output "[${date}] Installing drivers from ${DriverPath}"

	$CertStore = Get-Item "cert:\LocalMachine\TrustedPublisher"
	$CertStore.Open([System.Security.Cryptography.X509Certificates.OpenFlags]::ReadWrite)

	Get-ChildItem $DriverPath.FullName -Recurse -Filter *.sys | Foreach-Object {
		$Cert = (Get-AuthenticodeSignature $_.FullName).SignerCertificate
		if ($Cert) {
			Write-Host("Adding certificate {0}, {1} from {2} to {3} store" -f $Cert.Thumbprint, $Cert.Subject, $_.FullName, $CertStore.Name)
		}
		else {
			Write-Host("No certificate found in {0}" -f $_.FullName)
		}
		$CertStore.Add($Cert)
	}
	$CertStore.Close()

	New-Item -Path "HKLM:\SOFTWARE\Microsoft\Windows NT\CurrentVersion\UnattendSettings\PnPUnattend\DriverPaths" -Name 1 -Force
	New-ItemProperty -Path "HKLM:\SOFTWARE\Microsoft\Windows NT\CurrentVersion\UnattendSettings\PnPUnattend\DriverPaths\1" -Name Path -Value $DriverPath.FullName -Force
	pnpunattend.exe AuditSystem /L
	Remove-Item -Path "HKLM:\SOFTWARE\Microsoft\Windows NT\CurrentVersion\UnattendSettings\PnPUnattend\DriverPaths\1" -Recurse -Force
}
else {
	Write-Output "[${date}] Driver directory ${Env:drv_dir} does not exist"
}
